==> xlniuxdata-vipgame-1.0.65-20170428.033419-75-sources.jar: com/xunlei/niux/data/vipgame/dto/gamedata/GameDataOnAdv.java <==
package com.xunlei.niux.data.vipgame.dto.gamedata;



/**
 * @author ljm
 * @date 2017-4-12
 * @Descripter:
 */
public class GameDataOnAdv {
	private Long fdate;
	private String adv_no;
	private String game_id;
	private String server_id;
	private Long login_users;
	private Long login_account;
	private Long pay_users;
	private Double pay_amount;
	private Double arpu;
	private Double pay_ratio;
	private Long login_account_new;
	private Long pay_users1_new;
	private Double pay_amount1_new;
	private Double new_account_arpu;
	private Double new_account_pay_ratio;
	public Long getFdate() {
		return fdate;
	}
	public void setFdate(Long fdate) {
		this.fdate = fdate;
	}
	public String getAdv_no() {
		return adv_no;
	}
	public void setAdv_no(String adv_no) {
		this.adv_no = adv_no;
	}
	public String getGame_id() {
		return game_id;
	}
	public void setGame_id(String game_id) {
		this.game_id = game_id;
	}
	public String getServer_id() {
		return server_id;
	}
	public void setServer_id(String server_id) {
		this.server_id = server_id;
	}
	public Long getLogin_users() {
		return login_users;
	}
	public void setLogin_users(Long login_users) {
		this.login_users = login_users;
	}
	public Long getLogin_account() {
		return login_account;
	}
	public void setLogin_account(Long login_account) {
		this.login_account = login_account;
	}
	public Long getPay_users() {
		return pay_users;
	}
	public void setPay_users(Long pay_users) {
		this.pay_users = pay_users;
	}
	public Double getPay_amount() {
		return pay_amount;
	}
	public void setPay_amount(Double pay_amount) {
		this.pay_amount = pay_amount;
	}
	public Double getArpu() {
		return arpu;
	}
	public void setArpu(Double arpu) {
		this.arpu = arpu;
	}
	public Double getPay_ratio() {
		return pay_ratio;
	}
	public void setPay_ratio(Double pay_ratio) {
		this.pay_ratio = pay_ratio;
	}
	public Long getLogin_account_new() {
		return login_account_new;
	}
	public void setLogin_account_new(Long login_account_new) {
		this.login_account_new = login_account_new;
	}
	public Long getPay_users1_new() {
		return pay_users1_new;
	}
	public void setPay_users1_new(Long pay_users1_new) {
		this.pay_users1_new = pay_users1_new;
	}
	public Double getPay_amount1_new() {
		return pay_amount1_new;
	}
	public void setPay_amount1_new(Double pay_amount1_new) {
		this.pay_amount1_new = pay_amount1_new;
	}
	public Double getNew_account_arpu() {
		return new_account_arpu;
	}
	public void setNew_account_arpu(Double new_account_arpu) {
		this.new_account_arpu = new_account_arpu;
	}
	public Double getNew_account_pay_ratio() {
		return new_account_pay_ratio;
	}
	public void setNew_account_pay_ratio(Double new_account_pay_ratio) {
		this.new_account_pay_ratio = new_account_pay_ratio;
	}
	
}

==> xlniuxdata-vipgame-1.0.65-20171114.063132-114-sources.jar: com/xunlei/niux/data/vipgame/dto/gamedata/GameDataOnAdv.java <==
package com.xunlei.niux.data.vipgame.dto.gamedata;



/**
 * @author ljm
 * @date 2017-4-12
 * @Descripter:
 */
public class GameDataOnAdv {
	private Long fdate;
	private String adv_no;
	private String game_id;
	private String server_id;
	private Long login_users;
	private Long login_account;
	private Long pay_users;
	private Double pay_amount;
	private Double arpu;
	private Double pay_ratio;
	private Long login_account_new;
	private Long pay_users1_new;
	private Double pay_amount1_new;
	private Double new_account_arpu;
	private Double new_account_pay_ratio;
	
	//推广平台 added by ljm  增加渠道名
	private String flatno;
	//推广位  added by ljm 增加渠道名
	private String spreadTab;
	
	public String getFlatno() {
		return flatno;
	}
	public void setFlatno(String flatno) {
		this.flatno = flatno;
	}
	public String getSpreadTab() {
		return spreadTab;
	}
	public void setSpreadTab(String spreadTab) {
		this.spreadTab = spreadTab;
	}
	public Long getFdate() {
		return fdate;
	}
	public void setFdate(Long fdate) {
		this.fdate = fdate;
	}
	public String getAdv_no() {
		return adv_no;
	}
	public void setAdv_no(String adv_no) {
		this.adv_no = adv_no;
	}
	public String getGame_id() {
		return game_id;
	}
	public void setGame_id(String game_id) {
		this.game_id = game_id;
	}
	public String getServer_id() {
		return server_id;
	}
	public void setServer_id(String server_id) {
		this.server_id = server_id;
	}
	public Long getLogin_users() {
		return login_users;
	}
	public void setLogin_users(Long login_users) {
		this.login_users = login_users;
	}
	public Long getLogin_account() {
		return login_account;
	}
	public void setLogin_account(Long login_account) {
		this.login_account = login_account;
	}
	public Long getPay_users() {
		return pay_users;
	}
	public void setPay_users(Long pay_users) {
		this.pay_users = pay_users;
	}
	public Double getPay_amount() {
		return pay_amount;
	}
	public void setPay_amount(Double pay_amount) {
		this.pay_amount = pay_amount;
	}
	public Double getArpu() {
		return arpu;
	}
	public void setArpu(Double arpu) {
		this.arpu = arpu;
	}
	public Double getPay_ratio() {
		return pay_ratio;
	}
	public void setPay_ratio(Double pay_ratio) {
		this.pay_ratio = pay_ratio;
	}
	public Long getLogin_account_new() {
		return login_account_new;
	}
	public void setLogin_account_new(Long login_account_new) {
		this.login_account_new = login_account_new;
	}
	public Long getPay_users1_new() {
		return pay_users1_new;
	}
	public void setPay_users1_new(Long pay_users1_new) {
		this.pay_users1_new = pay_users1_new;
	}
	public Double getPay_amount1_new() {
		return pay_amount1_new;
	}
	public void setPay_amount1_new(Double pay_amount1_new) {
		this.pay_amount1_new = pay_amount1_new;
	}
	public Double getNew_account_arpu() {
		return new_account_arpu;
	}
	public void setNew_account_arpu(Double new_account_arpu) {
		this.new_account_arpu = new_account_arpu;
	}
	public Double getNew_account_pay_ratio() {
		return new_account_pay_ratio;
	}
	public void setNew_account_pay_ratio(Double new_account_pay_ratio) {
		this.new_account_pay_ratio = new_account_pay_ratio;
	}
	
}
